package com.link.core.kernelbuslog;

import com.alibaba.fastjson.JSON;
import com.link.base.user.model.CoreUser;
import com.link.core.basic.service.KeyGenerateService;
import com.link.core.kafka.KafkaTemplateFacotry;
import com.link.core.kernelbuslog.model.KernelBusLogModel;
import com.link.core.util.DateUtil;
import com.link.core.util.SpringUtil;
import com.link.core.util.UserUtil;
import java.util.Date;
import java.util.List;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class KernelBusLogUtils {
   private static String KERNEL_BUS_LOG_TOPIC = "KERNEL_BUS_LOG_TOPIC";
   private static Logger logger = LoggerFactory.getLogger(KernelBusLogUtils.class);
   private static ThreadLocal<List<KernelBusLogModel>> KAFKA_BUSLOGS = new ThreadLocal();

   public static void publish(KernelBusLogModel kernelBusLogModel) {
      String content = JSON.toJSONString(kernelBusLogModel);
      String key = kernelBusLogModel.getParentId();
      logger.info("核心日志对象id：" + key + "，日志内容：" + content);
      KafkaTemplateFacotry.send(KERNEL_BUS_LOG_TOPIC, content, key);
   }

   public static void publish(String parentId, String logType, String operate, JSON json) {
      KeyGenerateService keyGenerateService = (KeyGenerateService)SpringUtil.getBean(KeyGenerateService.class);
      String currentDate = DateUtil.dateToStr(new Date(), (String)null);
      CoreUser user = UserUtil.getUser();
      KernelBusLogModel kernelBusLogModel = new KernelBusLogModel();
      kernelBusLogModel.setId(keyGenerateService.keyGenerate());
      kernelBusLogModel.setParentId(parentId);
      kernelBusLogModel.setCreated(currentDate);
      kernelBusLogModel.setLastUpdated(currentDate);
      kernelBusLogModel.setCreatedBy(user.getId());
      kernelBusLogModel.setCreatedUser(user.getFirstName());
      kernelBusLogModel.setLastUpdatedBy(user.getId());
      kernelBusLogModel.setOrgId(user.getOrgId());
      kernelBusLogModel.setPostnId(user.getPostnId());
      kernelBusLogModel.setLoginCorpId(user.getCorpid());
      kernelBusLogModel.setCorpid(user.getCorpid());
      kernelBusLogModel.setLogType(logType);
      kernelBusLogModel.setJson(json);
      kernelBusLogModel.setContentType("Json");
      kernelBusLogModel.setOperate(operate);
      publish(kernelBusLogModel);
   }

   public static void publishHtml(String parentId, String logType, String operate, String html) {
      KeyGenerateService keyGenerateService = (KeyGenerateService)SpringUtil.getBean(KeyGenerateService.class);
      String currentDate = DateUtil.dateToStr(new Date(), (String)null);
      CoreUser user = UserUtil.getUser();
      KernelBusLogModel kernelBusLogModel = new KernelBusLogModel();
      kernelBusLogModel.setId(keyGenerateService.keyGenerate());
      kernelBusLogModel.setParentId(parentId);
      kernelBusLogModel.setCreated(currentDate);
      kernelBusLogModel.setLastUpdated(currentDate);
      kernelBusLogModel.setCreatedBy(user.getId());
      kernelBusLogModel.setCreatedUser(user.getFirstName());
      kernelBusLogModel.setLastUpdatedBy(user.getId());
      kernelBusLogModel.setOrgId(user.getOrgId());
      kernelBusLogModel.setPostnId(user.getPostnId());
      kernelBusLogModel.setLoginCorpId(user.getCorpid());
      kernelBusLogModel.setCorpid(user.getCorpid());
      kernelBusLogModel.setLogType(logType);
      kernelBusLogModel.setOperate(operate);
      kernelBusLogModel.setHtml(html);
      kernelBusLogModel.setContentType("Html");
      publish(kernelBusLogModel);
   }
}
